# replit-py

Replit-py is a python library designed to be run from a repl on [repl.it](https://repl.it).

### Features

- Fully featured database client for Repl DB
- Audio library which can play tones and files
- Clear the terminal

### Documentation

The documentation can be found [here](https://replit-python-docs.scoder12.repl.co).
